function ZLBData = INITIAL_CHECKS( TShadow, TIRF, Var_cons, var_list_ )

% This function tests the feasibility of a model containing a zero lower bound, and performs necessary pre-computations for either IRF or simulations.
% Details on the algorithm can be found in Holden, Thomas and Michael Paetz ( 2012 ), "Efficient Simulation of DSGE Models with Inequality Constraints"
% Thomas Holden and Michael Paetz, June 7, 2012
%
% INPUTS 
% ------
% TShadow:      Number of periods you predict the constraint to bind.
% TIRF:         Number of periods to generate impulse response functions for. Must be larger than Tshadow.
% Var_cons:     String with the name of the constrained variable.
% var_list_:    Char Array of variables to generate impulse response functions for
%
% OUTPUTS
% -------
% ZLBData:		Structure containing the required data to call STEADYSTATE_IRF_CONS or AVERAGE_SIMU_CONS
%
% EXAMPLE
% -------
% ZLBData = INITIAL_CHECKS( 10, 20, 'i', var_list_ )

	global M_
	
	if TIRF < TShadow
		error( 'ZLB:SmallTIRF', 'INITIAL_CHECKS was called with a value of TIRF less than TShadow.' );
	end
	if TShadow <= 1
		error( 'ZLB:SmallTShadow', 'INITIAL_CHECKS was called with a value of TShadow less or equal to 1.' );
    end
    ZeroVec = zeros( TShadow, 1 );
	OneVec = ones( size( ZeroVec ) );
    M = zeros( TIRF, TShadow );
 
	for indx = 0:( TShadow - 1 )
		M( :, indx + 1 ) = GetRelIRF( Var_cons, [ 'epsilon_shadow_' int2str( indx ) ], TIRF );
	end
    disp('program working')
	
	if min( diag( M ) ) <= 0
		%keyboard;
		error( 'ZLB:MDiagonal', 'M does not have a positive diagonal.' );
	end

	seps = sqrt( eps );
	CompVec = false( TIRF, 1 );
	GuaranteedHorizon = 0;

	for GH = 1:TIRF
		CompVec( GH ) = true;
		AlphaStart = linprog( OneVec, -M, -double( CompVec ), [ ], [ ], ZeroVec, [ ], [ ], optimset( 'display', 'off', 'LargeScale', 'on', 'MaxIter', 1000, 'TolFun', seps ) );
		if ( min( AlphaStart ) < -seps ) || ( min( M( CompVec, : ) * AlphaStart ) < 1-seps ) || ( min( M * AlphaStart ) < -seps )
			warning( 'ZLB:AlphaStart', [ 'There is only a guaranteed solution to the linear programming problem when the ZLB binds for at most ' int2str( GuaranteedHorizon ) ' periods.' ] );
			break;
		else
			GuaranteedHorizon = GH;
		end
	end
	
	ZLBData = struct;
	ZLBData.ZeroVec = ZeroVec;
	ZLBData.OneVec = OneVec;
	ZLBData.M = M;
	ZLBData.AlphaStart = AlphaStart;
	ZLBData.Options = optimset( 'MaxIter', 4096, 'LargeScale', 'off', 'Algorithm', 'active-set', 'display', 'off', 'TolX', seps, 'TolFun', seps );
%	ZLBData.Options = optimset( 'MaxIter', 4096, 'LargeScale', 'off', 'Algorithm', 'interior-point-convex', 'display', 'off', 'TolX', seps, 'TolFun', seps );
	ZLBData.Var_cons = Var_cons;
	ZLBData.Accuracy = seps;
	ZLBData.TShadow = TShadow;
	ZLBData.TIRF = TIRF;
	ZLBData.ExoVars = M_.exo_names( 1:( size( M_.exo_names, 1 ) - TShadow ), : );
	ZLBData.Vars = var_list_;
end
