% NKM_ZLB.mod
% New Keynesian Model with zero lower bound
% The model equations are taken from Gal( 2008 ), chapter 3, where we added a cost-push ( shock_pi ), a preference shock ( shock_nu ), and a monetary policy shock ( shock_i ).
% Michael Paetz and Tom Holden, June 2nd, 2012
% Based on Holden, Thomas and Michael Paetz ( 2012 ), "Efficient Simulation of DSGE Models with Inequality Constraints"
% 
% DEFINITIONS:
% ------------
% TShadow:  Number of periods you believe the ZLB binds
% TIRF:     Number of periods for IRF graphs
% TInitIRF: Number of periods for IRF simulation
% TSimul:   Number of periods for complete simulation
% TDrop:    Number of simulation periods to be dropped before plotting

@#define TShadow = 30   
@#define TIRF = 15    
@#define TSimul = 300   
@#define TDrop = 100    

@#if TShadow > TIRF
	@#define TInitIRF = TShadow
@#else
	@#define TInitIRF = TIRF
@#endif

%%%%%%%%%%%%%%%%%%%%%%%%% BEGINNING OF THE CONVENTIONAL .mod FILE %%%%%%%%%%%%%%%%%%%%%%%%%

var pi, y, i, shock_pi, shock_nu, shock_i;

varexo epsilon_pi, epsilon_nu, epsilon_i;

%%%%%%%%%%%%%%%%%%%%%>>> BEWARE! <<<%%%%%%%%%%%%%%%%%%%%%%%
% Shadow price shocks need to be the last shocks defined! %
% ------------------------------------------------------- %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for index in 0:( TShadow - 1 )
	varexo epsilon_shadow_@{index};
	var LAG0_shadow_@{index};
	@#for offset in 1:index
		var LAG@{offset}_shadow_@{index};
	@#endfor
	@#define offset = 10000000000
@#endfor
@#define index = 10000000000

parameters alpha, beta, kappa, lambda, phi, sigma, epsilon, omega, bigtheta, phi_pi, phi_i, phi_y, rho_pi, i_bar, rho_nu, rho_i;

beta = 0.995;
omega = 0.75;
epsilon = 6;
sigma = 1;
phi_pi = 1.5;
phi_i = 0.2;
phi_y = 0.125;
i_bar = 1/beta;
alpha = 0.33;
phi = 1;
bigtheta = ( ( 1 - alpha )/( 1 - alpha + alpha * epsilon ) );
lambda = ( ( ( 1-omega )*( 1-beta*omega ) )/omega )*bigtheta;
kappa = lambda * ( sigma + ( ( phi + alpha )/( 1 - alpha ) ) );
rho_pi = 0.7;
rho_nu = 0.7;
rho_i = 0.7;

model( linear );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 'shadow_price' is defined so that the shadow price shocks hit the equation of the constrained variable in consecutive periods: %
% ------------------------------------------------------------------------------------------------------------------------------ %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for index in 0:( TShadow - 1 )
    LAG0_shadow_@{index} = epsilon_shadow_@{index};
	@#for offset in 1:index
		LAG@{offset}_shadow_@{index}( 0 ) = LAG@{offset-1}_shadow_@{index}( -1 );
	@#endfor
	@#define offset = 10000000000
@#endfor
@#define index = 10000000000
	
#shadow_price = 0
@#for index in 0:( TShadow - 1 )
	+ LAG@{index}_shadow_@{index}( 0 )
@#endfor
@#define index = 10000000000
;

y = y( +1 ) - sigma^( -1 )*( i - log( i_bar ) - pi( +1 ) - ( 1 - rho_nu ) * shock_nu );

i = log( i_bar ) + phi_i * ( i( -1 ) - log( i_bar ) ) + ( 1 - phi_i ) * ( phi_pi * pi + phi_y * y ) + shock_i + shadow_price;

pi = beta * pi( +1 ) +  kappa* y + shock_pi;

shock_pi = rho_pi * shock_pi( -1 ) - 0.1 * epsilon_pi;

shock_nu = rho_nu * shock_nu( -1 ) - 0.1 * epsilon_nu;

shock_i = rho_i * shock_i( -1 ) -  0.1 * epsilon_i;

end;

initval;
y = 0;
pi = 0;
end;

check;
steady;

shocks;

var epsilon_pi; stderr 1;
var epsilon_nu; stderr 1;
var epsilon_i; stderr 1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Standard deviation of shadow price shocks is set to one: %
% -------------------------------------------------------- %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for index in 0:( TShadow - 1 )
	var epsilon_shadow_@{index} = 1;
@#endfor
@#define index = 10000000000

end;

t0 = tic;

stoch_simul( order = 1, irf = @{TInitIRF}, noprint, nograph, nomoments, periods=0 ) y pi i;

ZLBData = INITIAL_CHECKS( @{TShadow}, @{TInitIRF}, 'i', var_list_ );
display( sprintf( '\n%s', 'Computation time for set-up and initial feasibility checks:' ) ); toc( t0 ); 
t1 = tic;
[ IRF_, IRF_CONS_ ] = STEADYSTATE_IRF_CONS( ZLBData );
display( sprintf( '\n%s', 'Additional computation time for IRFs:' ) ); toc( t1 ); 
t2 = tic;
[ SIMU_, SIMU_CONS_ ] = SIMU_CONS(  ZLBData, @{TSimul} );
display( sprintf( '\n%s', 'Additional computation time for simulations:' ) ); toc( t2 );

%%%%%%%%%%%%%%%%%%%%%
% Generate Figures: %
% ----------------- %
%%%%%%%%%%%%%%%%%%%%%

exovars( 1, 1:( size( M_.exo_names, 1 ) - @{TShadow} ) ) = cellstr( M_.exo_names( 1:( size( M_.exo_names, 1 ) - @{TShadow} ), : ) );
vars( 1, 1:size( var_list_ ) ) = cellstr( var_list_( 1:size( var_list_ ), : ) );

xx =( 0:@{TIRF}-1 )';
for exovar = exovars
    @#define number = 0
    for var = vars
        @#define number = number +1
        figure( 'Name', cell2mat( [ 'IRF: ' var ', Shock: ' exovar ] ) );
        hold on;
        plot( xx, IRF_.( cell2mat( [ var '_' exovar ] ) )( 1:@{TIRF} ), '-k', 'MarkerSize', 4, 'LineWidth', 1.5 );
        plot( xx, IRF_CONS_.( cell2mat( [ var '_' exovar ] ) )( 1:@{TIRF} ), '--k', 'MarkerSize', 4, 'LineWidth', 1.5 );
        plot( xx, zeros( @{TIRF} )', '-k', 'MarkerSize', 2, 'LineWidth', 0.5 );
        set( gca, 'PlotBoxAspectRatio', [ 1 2 1 ] );  
        set( gca, 'fontsize', 25 ); 
        title(var);
        axis tight;
        hold off;
    end
end

yy =( 0:@{TSimul}-1-@{TDrop} )';
@#define number = 0
for var = vars
	@#define number = number +1
	figure( 'Name', cell2mat( [ 'Simulation: ' var ] ) );
	hold on;
	plot( yy, SIMU_.( cell2mat( [ var  ] ) )( 1:( @{TSimul}-@{TDrop} ) ), '-k', 'MarkerSize', 4, 'LineWidth', 1.5 );
	plot( yy, SIMU_CONS_.( cell2mat( [ var ] ) )( 1:( @{TSimul}-@{TDrop} ) ), '--k', 'MarkerSize', 4, 'LineWidth', 1.5 );
	plot( yy, zeros( @{TSimul}-@{TDrop} ), '-k', 'MarkerSize', 2, 'LineWidth', .5 );
	set( gca, 'PlotBoxAspectRatio', [ 2.5 1 1 ] );  
	set( gca, 'fontsize', 25 ); 
    title( var);
	axis tight;
	hold off;
end 

