function [ SIMU_, SIMU_CONS_ ] = SIMU_CONS( ZLBData, TSimul )

% This function generates simulations in a linear rational expectations model, where one variable is bounded by zero
% Details on the algorithm can be found in Holden, Thomas and Michael Paetz ( 2012 ), "Efficient Simulation of DSGE Models with Inequality Constraints"
% Thomas Holden and Michael Paetz, June 7, 2012
%
% INPUTS 
% ------
% ZLBData:      Structure generated by INITIAL_CHECKS
% TSimul:       Number of periods to generate simulations for
% 
% OUTPUTS
% -------
% SIMU_:        Structrue array of conventional simulations ignoring the constraint
% SIMU_CONS:    Structure array of simulations for the constrained model
%
% EXAMPLE
% -------
% [ SIMU_, SIMU_CONS_ ] = SIMU_CONS( 10, 20, 'i' )

	global M_ oo_

	ZeroVec = ZLBData.ZeroVec;
	OneVec = ZLBData.OneVec;
	AlphaStart = ZLBData.AlphaStart;
	Options = ZLBData.Options;
	Var_cons = ZLBData.Var_cons;
	Accuracy = ZLBData.Accuracy;
	TShadow = ZLBData.TShadow;
	M = ZLBData.M( 1:TShadow, : ); % only use the top block
	vars = ZLBData.Vars;

    % setup code mostly taken from Dynare

	i_exo_var = setdiff( 1:M_.exo_nbr, find( diag( M_.Sigma_e ) == 0 ) );
	nxs = length( i_exo_var );
	oo_.exo_simul = zeros( TSimul, M_.exo_nbr );
	chol_S = chol( M_.Sigma_e( i_exo_var, i_exo_var ) );

	if ~isempty( M_.Sigma_e )
		oo_.exo_simul( :, i_exo_var ) = randn( TSimul, nxs )*chol_S;
	end

	shadow_index = strmatch( 'LAG0_shadow_0', M_.endo_names, 'exact' ); %#ok<*MATCH3>
	epsilon_shadow_index = strmatch( 'epsilon_shadow_0', M_.exo_names, 'exact' );

    ex_ = oo_.exo_simul;
	ex_( :, epsilon_shadow_index:end ) = 0;
	dr = oo_.dr;
	iter = size( ex_, 1 );
	epsilon = dr.ghu*transpose( ex_ );
	k2 = dr.kstate( dr.kstate( :, 2 ) <= M_.maximum_lag+1, [ 1 2 ] );
	k2 = k2( :, 1 )+( M_.maximum_lag+1-k2( :, 2 ) )*M_.endo_nbr;
	order_var = dr.order_var;

	Var_cons_index = strmatch( Var_cons, M_.endo_names, 'exact' );
	Var_cons_steady = dr.ys( Var_cons_index );
	SIMU_CONS = zeros( size( dr.ys, 1 ), iter+M_.maximum_lag );
	SIMU = SIMU_CONS;

	% Starting the simulation

	disp( 'Starting simulation. Please be patient.' );

	LongestBindPeriod = 0;
	CurrentBindPeriod = 0;
	for i = 2:iter+M_.maximum_lag
		yhat = SIMU_CONS( order_var( k2 ), i-1 );
		yhat2 = SIMU( order_var( k2 ), i-1 );
		epstmp = epsilon( :, i-1 );
		SIMU( order_var, i ) = dr.ghx*yhat2 + epstmp;
		V = ZeroVec;
		temp_current_SIMU_CONS = zeros( length( dr.ys ), 1 );
		temp_current_SIMU_CONS( order_var ) = dr.ghx * yhat + epstmp;
		V( 1 ) = Var_cons_steady + temp_current_SIMU_CONS( Var_cons_index );
	    for j = 2:TShadow
			temp_current_SIMU_CONS( order_var ) = dr.ghx * temp_current_SIMU_CONS( order_var( k2 ) );
			V( j ) = Var_cons_steady + temp_current_SIMU_CONS( Var_cons_index );
		end

		alpha = solve_quadprog( M, V, AlphaStart, TShadow, Accuracy, Options, ZeroVec, OneVec );

		ex_temp = ex_( i-1, : );
		ex_temp( epsilon_shadow_index:end ) = alpha;
		SIMU_CONS( order_var, i ) = dr.ghx*yhat + dr.ghu*transpose( ex_temp );
		if alpha( 1 ) > Accuracy
			CurrentBindPeriod = CurrentBindPeriod + 1;
		else
			if CurrentBindPeriod > LongestBindPeriod
				LongestBindPeriod = CurrentBindPeriod;
			end
			CurrentBindPeriod = 0;
		end
			
		SIMU_CONS( shadow_index:end, i )  = 0;
		SIMU( shadow_index:end, i ) = 0;
	end

	if LongestBindPeriod > TShadow
		warning( 'ZLB:ParanoidInaccuracy', '[Paranoid] ZLB simulations may be inaccurate, as the constraint binds for more than TShadow periods along the simulated path.' );
	end

	% Save results

	for varIndex = 1:size( vars, 1 )
		var = strtrim( vars( varIndex, : ) );
		SIMU_.( var ) = SIMU( strmatch( var , M_.endo_names, 'exact' ), 1:TSimul );
		SIMU_CONS_.( var ) = SIMU_CONS( strmatch( var , M_.endo_names, 'exact' ), 1:TSimul );
    end
end

