function [ IRF_, IRF_CONS_ ] = STEADYSTATE_IRF_CONS( ZLBData )

% This function generates steady state impulse responses in a linear rational expectations model, where one variable is bounded by zero
% Details on the algorithm can be found in Holden, Thomas and Michael Paetz ( 2012 ), "Efficient Simulation of DSGE Models with Inequality Constraints"
% Thomas Holden and Michael Paetz, June 7, 2012
%
% INPUTS 
% ------
% ZLBData:      Structure generated by INITIAL_CHECKS
%
% OUTPUTS
% -------
% IRF:          Structrue array of conventional impulse response functions ignoring the constraint
% IRF_CONS:     Structure array of impulse response functions for the constrained model
%
% EXAMPLE
% -------
% ZLBData = INITIAL_CHECKS( 10, 20, 'i', var_list_ );
% [ IRF_, IRF_CONS_ ] = STEADYSTATE_IRF_CONS( ZLBData, var_list_ );

ZeroVec = ZLBData.ZeroVec;
OneVec = ZLBData.OneVec;
M = ZLBData.M;
AlphaStart = ZLBData.AlphaStart;
Options = ZLBData.Options;
Accuracy = ZLBData.Accuracy;
TShadow = ZLBData.TShadow;
TIRF = ZLBData.TIRF;
Var_cons = ZLBData.Var_cons;
exovars = ZLBData.ExoVars;
vars = ZLBData.Vars;

for exovarIndex = 1:size( exovars, 1 )
	exovar = strtrim( exovars( exovarIndex, : ) );

	V = GetIRF( Var_cons, exovar, TIRF );
 
    alpha = solve_quadprog( M, V, AlphaStart, TShadow, Accuracy, Options, ZeroVec, OneVec );
    
	for varIndex = 1:size( vars, 1 )
		var = strtrim( vars( varIndex, : ) );
		IRF_.( [ var '_' exovar ] ) = GetIRF( var, exovar, TIRF );
		IRF_CONS_.( [ var '_' exovar ] ) = GetBoundedIRF( var, exovar, alpha, TIRF );
	end
end

            


