function [ alpha, FoundValue, exitflag ] = solve_quadprog( M, V, AlphaStart, TShadow, Accuracy, Options, ZeroVec, OneVec )

% Function to solve for alpha in the quadratic optimisation problem, described in section 2.1 of Holden, Thomas and Michael Paetz ( 2012 ), "Efficient Simulation of DSGE Models with Inequality Constraints":
%
% alpha = argmin { 0.5*alpha'*( M_Sub + M_Sub' )*alpha + V_Sub'*alpha   subject to:  M*alpha >= 0 }
% 
% where M_Sub = M( 1:TShadow, : ) and V_Sub = V( 1:TShadow ).
%
% The resulting alpha can be used to compute simulations of the constrained variable.
%
% Thomas Holden and Michael Paetz, June 7, 2012
%
% INPUTS 
% ------
% M:            Matrix formed from horizontally concatenating column vectors of the relative impulse responses of the bounded variable
% V:            Matrix of the unconstrained relative IRFs of the constrained variable
% AlphaStart:   Start value for alpha
% TShadow:      Number of periods, the constraint is binding
% Accuracy:		[Optional] Permitted amount of constraint violation
% Options:		[Optional] quadprog options structure
% ZeroVec:		[Optional] Optional argument to save on unnecessary memory allocations
% OneVec:		[Optional] Optional argument to save on unnecessary memory allocations
%
% OUTPUTS
% -------
% alpha:        Vector that determines the size for each shadow shock to keep the constrained variable bounded by zero

	% Get an initial approximation for alpha to increase the stability and the speed of the computation

	if nargin < 7
		ZeroVec = zeros( TShadow, 1 );
		OneVec = ones( size( ZeroVec ) );
		if nargin < 6
			Options = optimset;
			if nargin < 5
				Accuracy = sqrt( eps );
			end
		end
	end
	M_Sub = M( 1:TShadow, : );
	V_Sub = V( 1:TShadow );
 	alpha = AlphaStart * max( 0, max( -V_Sub ) );
    V_Candidate = V_Sub + M_Sub * alpha;
	indices = [ ];
	for conv_iter = 1:TShadow
		indices = union( indices, find( V_Candidate < -Accuracy ) );
		if isempty( indices )
			break;
		end
		oldalpha = alpha;
		alpha( indices ) = max( ZeroVec( indices ), alpha( indices ) - M_Sub( indices, indices ) \ V_Candidate( indices ) );
		indices = setdiff( indices, find( alpha < Accuracy ) );
		V_Candidate = V_Sub + M_Sub * alpha;
		if min( V_Candidate ) >= -Accuracy || norm( oldalpha - alpha ) < Accuracy
			break;
		end
	end
    
	if min( V_Candidate ) < -Accuracy
		alpha = max( ZeroVec, linprog( OneVec, -M_Sub, V_Sub, [ ], [ ], ZeroVec, [ ], [ ], optimset( 'LargeScale', 'on', 'MaxIter', 1000, 'TolFun', Accuracy ) ) ); 
		V_Candidate = V_Sub + M_Sub * alpha;
	end
	if min( V_Candidate ) < -Accuracy
		warning( 'ZLB:InitialFeasiblePoint',  'Failed to find initial feasible point.\n' );
	end

	% Solve the quadratic optimisation problem

    [ alpha, FoundValue, exitflag ] = quadprog( M_Sub + M_Sub', V_Sub, -M, V, [ ], [ ], ZeroVec, [ ], alpha, Options );
    
	if FoundValue >= Accuracy || exitflag <= 0
		error( 'ZLB:quadprog', 'Failed to solve quadratic programming problem. Try increasing TShadow.' );
	end
	if alpha( end ) > Accuracy
		warning( 'ZLB:Inaccuracy', 'The final component of alpha is equal to %e > 0. This is indicative of TShadow being too small.', alpha( end ) );
	end
end