// Model_IRF_PEI_0518.mod
// This model includes sticky prices, a downward rigidity on nominal wages, and oil prices.
// This model assume the taylor rule deviates from potential output
// This file inputs the linear model in Dynare and the Holden software.
// This model was last updated November 19, 2021

// DEFINITIONS:
// ------------
// TShadow:  Number of periods you believe the ZLB binds
// TIRF:     Number of periods for IRF graphs
// TInitIRF: Number of periods for IRF simulation
// TSimul:   Number of periods for complete simulation
// TDrop:    Number of simulation periods to be dropped before plotting

@#define TShadow =60   
@#define TIRF = 15    
@#define TSimul = 300   
@#define TDrop = 100    

@#if TShadow > TIRF
	@#define TInitIRF = TShadow
@#else
	@#define TInitIRF = TIRF
@#endif

var n c cn i y ye R q w k lambda1 lambda2 lambda3 mc PII PIIc PIIe pe pn e ec ey r dPw; // 
var nf cf cnf if yf yef Rf qf wf kf lambda1f lambda2f lambda3f mcf PIIf PIIcf PIIef pnf ef ecf eyf dPwf; // 
varexo e_e; //  

//%%%%%%%%%%%%%%%%%%%%>>> BEWARE! <<<%%%%%%%%%%%%%%%%%%%%%%%
// Shadow price shocks need to be the last shocks defined! %
// ------------------------------------------------------- %
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for index in 0:( TShadow - 1 )
	varexo epsilon_shadow_@{index};
	var LAG0_shadow_@{index};
	@#for offset in 1:index
		var LAG@{offset}_shadow_@{index};
	@#endfor
	@#define offset = 10000000000
@#endfor
@#define index = 10000000000

parameters Rss qss a ky yn yss yess kss wss eyss iss css cnss ecss ess mcss phin lambda1ss lambda2ss lambda3ss dPwss;
parameters epsilonp etap kappa alpha vf vh delta beta phic xi nss pess pnss PIIstarss gammaP gammaW eyratio eccratio cncratio b1 b2; 
parameters thetaR thetaPII thetay sigpe rhop mup; 
parameters sige_e;   

//*******************************************
// Note: nonenergy output = y
//       output including energy = ye
//*******************************************

//*******************************************
// Calibrated Parameters
//*******************************************

epsilonp=6;          // 20% markup of prices over marginal cost
etap=0.75;           // probability of non-price adjustment
gammaP=1.00;         // degree of price indexation to lagged inflation
gammaW=1.00;         // degree of indexation odownward nominal wage rigidity
kappa=2.5;           // investment adjustment cost parameter       
alpha=0.33;          // capital's share of output
vf=-0.9;             // CES variable in production function
vh=-0.9;             // CES variable in household aggregate consumption
delta=0.025;         // steady-state capital depreciation rate
beta=1/1.01;         // discount factor 
phic=0.7;            // habit persistence in consumption parameter
xi=1/0.72;           // The inverse of the labor supply elasticity (ex., xi=1/2 means LSE=2)
nss=0.3;             // steady state labor
pess=1;              // steady state relative price of energy 
pnss=1;              // steady state relative price of non-energy goods 
PIIstarss=1.005;  //1.02;  // steady state gross inflation rate
eyratio=0.045;   //0.040;//0.056; // energy's share used in the production of output
eccratio=0.060;  //0.051;//0.073; // energy's share of consumption
cncratio=1-eccratio; // nonenergy's share of consumption
b1=eccratio^(1-vh);  // parameter in CES utility function
b2=cncratio^(1-vh);  // parameter in CES utility function

// Monetary Policy Rule Parmameters
thetaR=0.7; /0.44;/  // parameter on lagged interest rate
thetaPII=1.5; // 1.1;// parameter on headline inflation in the policy rule, 
thetay=0.125; //0.65/4; // parameter on output in the monetary policy rule, model 

// Exogenous Process Parameters
rhop=0.95;           // AR coefficient on the energy price shock
mup=0;               // MA coefficient on the energy price shock

sige_e=1.0;          // standard deviation of energy shock
sigpe= 0.35;         // Size of shock

//*******************************************
// Steady State Values
//*******************************************

mcss=(epsilonp-1)/epsilonp;
Rss=PIIstarss/beta; // Rss is the gross nominal interest rate
qss=((1/beta)-1+delta);
a=((eyratio*pess/(pnss))^(vf-1))*(qss^vf)/(((eyratio*pess/(pnss))^(vf-1))*(qss^vf)+((alpha*mcss-(eyratio*pess/pnss))^(vf-1))*((pess/pnss)^vf));
ky=((qss*(1-a)*pnss/(pess*a))^(1/(vf-1)))*eyratio;
yn=((a*(ky^vf)+(1-a)*(eyratio^vf))^(alpha/vf))^(1/(1-alpha));
yss=yn*nss;
kss=ky*yss;
wss=(1-alpha)*mcss*yn*pnss;
eyss=eyratio*yss;                                          
iss=delta*kss;
cnss=yss-iss;
css=cnss/cncratio;
ecss=css*eccratio;
ess=ecss+eyss;
//lambda1ss=(1-beta*phic)/(vh*(1-phic)*(css^vh));
lambda1ss=1/(vh*(1-phic)*(css^vh));
lambda2ss=lambda1ss*b2*vh*(cnss^(vh-1))/pnss;
lambda3ss=lambda2ss*pnss;
phin=wss*lambda2ss/(nss^xi);
yess=pnss*yss+pess*ess;
dPwss=PIIstarss;
 
//***********************************************
// Linearized Model:  See appendix for equations
//***********************************************

model (linear);
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// 'shadow_price' is defined so that the shadow price shocks hit the equation of the constrained variable in consecutive periods: %
// ------------------------------------------------------------------------------------------------------------------------------ %
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for index in 0:( TShadow - 1 )
    LAG0_shadow_@{index} = epsilon_shadow_@{index};
	@#for offset in 1:index
		LAG@{offset}_shadow_@{index}( 0 ) = LAG@{offset-1}_shadow_@{index}( -1 );
	@#endfor
	@#define offset = 10000000000
@#endfor
@#define index = 10000000000
	
#shadow_price = 0
@#for index in 0:( TShadow - 1 )
	+ LAG@{index}_shadow_@{index}( 0 )
@#endfor
@#define index = 10000000000
;

(css^vh)*c = b1*(ecss^vh)*ec + b2*(cnss^vh)*cn; // aggregate consumption
k = iss/kss*i + (1-delta)*k(-1); // capital accumulation equation
//beta*phic*c(+1)+phic*c(-1)-(1+beta*(phic^2)+(vh-1)*vh*lambda1ss*(css^(vh-1)))*c = vh*lambda1ss*(css^(vh-1))*lambda1; //foc aggregate consumption
//beta*phic*c(+1)+phic*c(-1)-(1+beta*(phic^2)+(vh-1)*(1-phic)*(1-beta*phic))*c = (1-phic)*(1-beta*phic)*lambda1; //foc aggregate consumption
phic*c(-1)-(1 +(vh-1)*(1-phic))*c = (1-phic)*lambda1; //foc aggregate consumption
lambda1 + (vh-1)*cn = lambda2 + pn; //foc nonenergy consumption
lambda1 + (vh-1)*ec = lambda2 + pe; //foc energy consumption
w  = xi*n - lambda2 + shadow_price; //foc labor
dPw = w - w(-1) + PII + log(dPwss) - log(gammaW); 
lambda2 - R = lambda2(+1) - PII(+1); //foc bonds
pn + lambda2 = lambda3 + kappa*beta*i(+1) - kappa*(1+beta)*i + kappa*i(-1); // foc investment
(1/beta)*lambda3 = qss*(lambda2(+1)+q(+1)+pn(+1)) + (1 - delta)*lambda3(+1);  
y =	(1-alpha)*n + (alpha/(a*(kss^vf)+(1-a)*(eyss^vf)))*(a*(kss^vf)*k(-1)+(1-a)*(eyss^vf)*ey); 
y =	(cnss/yss)*cn + (iss/yss)*i; // y = cn + i
w - pn = mc + y - n; // Firm foc for labor
q =	mc + y + (vf-1-(vf*a*(kss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))))*k(-1)-(vf*(1-a)*(eyss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf)))*ey;
pe - pn = mc + y + (vf-1-(vf*(1-a)*(eyss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))))*ey-vf*a*(kss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))*k(-1);
0 = (pess*ess/yess)*pe + (pnss*yss/yess)*pn;    //headline GDP deflator
yess*PII = pnss*yss*PIIc + pess*ess*PIIe;
ye = (pnss*yss/(yess))*(y + pn) + (pess*ess/(yess))*(pe + e);
//etap*PIIc = (1-etap)*(1-etap*beta)*mc + beta*etap*PIIc(+1);
(1+beta*gammaP)*etap*PIIc = (1-etap)*(1-etap*beta)*mc + beta*etap*PIIc(+1) + etap*gammaP*PIIc(-1);
ess*e = ecss*ec + eyss*ey;
pe = rhop*pe(-1) + sigpe*e_e + sigpe*mup*e_e(-1); // energy shock
//R = thetaR*R(-1)+(1-thetaR)*((thetaPII)*PII + thetay*(y - yf));  // Monetary policy responds to headline inflation 
//R = thetaR*R(-1)+(1-thetaR)*((thetaPII)*PIIc + thetay*(y));      // Monetary policy responds to steady-state output   
R = thetaR*R(-1)+(1-thetaR)*((thetaPII)*PIIc + thetay*(y - yf));   // Baseline monetary policy rule
PIIe=pe-pe(-1)+PII;
R = r + PII(+1); //Real interest rate

// Potential output equations
(css^vh)*cf = b1*(ecss^vh)*ecf + b2*(cnss^vh)*cnf; // aggregate consumption
kf = iss/kss*if + (1-delta)*kf(-1); // capital accumulation equation
//beta*phic*cf(+1)+phic*cf(-1)-(1+beta*(phic^2)+(vh-1)*vh*lambda1ss*(css^(vh-1)))*cf = vh*lambda1ss*(css^(vh-1))*lambda1f; //foc aggregate consumption
//beta*phic*cf(+1)+phic*cf(-1)-(1+beta*(phic^2)+(vh-1)*(1-phic)*(1-beta*phic))*cf = (1-phic)*(1-beta*phic)*lambda1f; //foc aggregate consumption
phic*cf(-1)-(1 +(vh-1)*(1-phic))*cf = (1-phic)*lambda1f; //foc aggregate consumption
lambda1f + (vh-1)*cnf = lambda2f + pnf; //foc nonenergy consumption
lambda1f + (vh-1)*ecf = lambda2f + pe; //foc energy consumption
wf  = xi*nf - lambda2f; //foc labor
dPwf = wf - wf(-1) + PIIf + log(dPwss) - log(gammaW); 
lambda2f - Rf = lambda2f(+1) - PIIf(+1); //foc bonds
pnf + lambda2f = lambda3f + kappa*beta*if(+1) - kappa*(1+beta)*if + kappa*if(-1); // foc investment
(1/beta)*lambda3f = qss*(lambda2f(+1)+qf(+1)+pnf(+1)) + (1 - delta)*lambda3f(+1);  
yf = (1-alpha)*nf + (alpha/(a*(kss^vf)+(1-a)*(eyss^vf)))*(a*(kss^vf)*kf(-1)+(1-a)*(eyss^vf)*eyf); 
yf = (cnss/yss)*cnf + (iss/yss)*if; // y = cn + i
wf - pnf = mcf + yf - nf; // Firm foc for labor
qf = mcf + yf + (vf-1-(vf*a*(kss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))))*kf(-1)-(vf*(1-a)*(eyss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf)))*eyf;
pe - pnf = mcf + yf + (vf-1-(vf*(1-a)*(eyss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))))*eyf-vf*a*(kss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))*kf(-1);
0 = (pess*ess/yess)*pe + (pnss*yss/yess)*pnf;    //headline GDP deflator
yess*PIIf = pnss*yss*PIIcf + pess*ess*PIIef;
yef = (pnss*yss/(yess))*(yf + pnf) + (pess*ess/(yess))*(pe + ef);
(1+beta*gammaP)*etap*PIIcf = (1-etap)*(1-etap*beta)*mcf + beta*etap*PIIcf(+1) + etap*gammaP*PIIcf(-1);
ess*ef = ecss*ecf + eyss*eyf;
Rf = thetaR*Rf(-1)+(1-thetaR)*thetaPII*PIIcf;   
PIIef=pe-pe(-1)+PIIf;

end;

check;
steady;

shocks;
var e_e; stderr sige_e;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Standard deviation of shadow price shocks is set to one: %
% -------------------------------------------------------- %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for index in 0:( TShadow - 1 )
	var epsilon_shadow_@{index} = 1;
@#endfor
@#define index = 10000000000

end;

t0 = tic;

stoch_simul( order = 1, irf = @{TInitIRF}, noprint, nograph, nomoments, periods=0 ) y PIIc PIIe PII lambda1 lambda2 pn pe c cn ec ey k i n w q mc R dPw e;

//stoch_simul(irf = @{TInitIRF}, nomoments, periods=0 ) y PII R;

//stoch_simul(irf = @{TInitIRF}, noprint, nograph, nomoments, periods=0 ) y PII R;
 //stoch_simul(irf=200) R r PII;     

ZLBData = INITIAL_CHECKS( @{TShadow}, @{TInitIRF}, 'dPw', var_list_ );
display( sprintf( '\n%s', 'Computation time for set-up and initial feasibility checks:' ) ); toc( t0 ); 
t1 = tic;
[ IRF_, IRF_CONS_ ] = STEADYSTATE_IRF_CONS( ZLBData );
display( sprintf( '\n%s', 'Additional computation time for IRFs:' ) ); toc( t1 ); 
t2 = tic;
[ SIMU_, SIMU_CONS_ ] = SIMU_CONS(  ZLBData, @{TSimul} );
display( sprintf( '\n%s', 'Additional computation time for simulations:' ) ); toc( t2 );

%%%%%%%%%%%%%%%%%%%%%
% Generate Figures: %
% ----------------- %
%%%%%%%%%%%%%%%%%%%%%

exovars( 1, 1:( size( M_.exo_names, 1 ) - @{TShadow} ) ) = cellstr( M_.exo_names( 1:( size( M_.exo_names, 1 ) - @{TShadow} ), : ) );
vars( 1, 1:size( var_list_ ) ) = cellstr( var_list_( 1:size( var_list_ ), : ) );

xx =( 0:@{TIRF}-1 )';
for exovar = exovars
    @#define number = 0
    for var = vars
        @#define number = number +1
//        figure( 'Name', cell2mat( [ 'IRF: ' var ', Shock: ' exovar ] ) );
//        hold on;
//        plot( xx, IRF_.( cell2mat( [ var '_' exovar ] ) )( 1:@{TIRF} ), '-k', 'MarkerSize', 4, 'LineWidth', 1.5 );
//        plot( xx, IRF_CONS_.( cell2mat( [ var '_' exovar ] ) )( 1:@{TIRF} ), '--k', 'MarkerSize', 4, 'LineWidth', 1.5 );
//        plot( xx, zeros( @{TIRF} )', '-k', 'MarkerSize', 2, 'LineWidth', 0.5 );
//        set( gca, 'PlotBoxAspectRatio', [ 1 2 1 ] );  
//        set( gca, 'fontsize', 25 ); 
//        title(var);
//        axis tight;
//        hold off;
    end
end

yy =( 0:@{TSimul}-1-@{TDrop} )';
@#define number = 0
for var = vars
	@#define number = number +1
//	figure( 'Name', cell2mat( [ 'Simulation: ' var ] ) );
//	hold on;
//	plot( yy, SIMU_.( cell2mat( [ var  ] ) )( 1:( @{TSimul}-@{TDrop} ) ), '-k', 'MarkerSize', 4, 'LineWidth', 1.5 );
//	plot( yy, SIMU_CONS_.( cell2mat( [ var ] ) )( 1:( @{TSimul}-@{TDrop} ) ), '--k', 'MarkerSize', 4, 'LineWidth', 1.5 );
//	plot( yy, zeros( @{TSimul}-@{TDrop} ), '-k', 'MarkerSize', 2, 'LineWidth', .5 );
//	set( gca, 'PlotBoxAspectRatio', [ 2.5 1 1 ] );  
//	set( gca, 'fontsize', 25 ); 
//    title( var);
//	axis tight;
//	hold off;
end 

imf_pe=IRF_.( cell2mat( [ 'pe_' exovar ] ) )( 1:@{TIRF} )*100;
imf_pn=IRF_.( cell2mat( [ 'pn_' exovar ] ) )( 1:@{TIRF} )*100;
imf_lambda1=IRF_.( cell2mat( [ 'lambda1_' exovar ] ) )( 1:@{TIRF} )*100;
imf_lambda2=IRF_.( cell2mat( [ 'lambda2_' exovar ] ) )( 1:@{TIRF} )*100;
imf_ey=IRF_.( cell2mat( [ 'ey_' exovar ] ) )( 1:@{TIRF} )*100;
imf_ec=IRF_.( cell2mat( [ 'ec_' exovar ] ) )( 1:@{TIRF} )*100;
imf_k=IRF_.( cell2mat( [ 'k_' exovar ] ) )( 1:@{TIRF} )*100;
imf_y=IRF_.( cell2mat( [ 'y_' exovar ] ) )( 1:@{TIRF} )*100;
imf_c=IRF_.( cell2mat( [ 'c_' exovar ] ) )( 1:@{TIRF} )*100;
imf_cn=IRF_.( cell2mat( [ 'cn_' exovar ] ) )( 1:@{TIRF} )*100;
imf_i=IRF_.( cell2mat( [ 'i_' exovar ] ) )( 1:@{TIRF} )*100;
imf_PII=IRF_.( cell2mat( [ 'PII_' exovar ] ) )( 1:@{TIRF} )*100;
imf_PIIc=IRF_.( cell2mat( [ 'PIIc_' exovar ] ) )( 1:@{TIRF} )*100;
imf_PIIpe=IRF_.( cell2mat( [ 'PIIe_' exovar ] ) )( 1:@{TIRF} )*100;
imf_R=IRF_.( cell2mat( [ 'R_' exovar ] ) )( 1:@{TIRF} )*100;
imf_n=IRF_.( cell2mat( [ 'n_' exovar ] ) )( 1:@{TIRF} )*100;
imf_w=IRF_.( cell2mat( [ 'w_' exovar ] ) )( 1:@{TIRF} )*100;
imf_q=IRF_.( cell2mat( [ 'q_' exovar ] ) )( 1:@{TIRF} )*100;
imf_mc=IRF_.( cell2mat( [ 'mc_' exovar ] ) )( 1:@{TIRF} )*100;
imf_dPw=IRF_.( cell2mat( [ 'dPw_' exovar ] ) )( 1:@{TIRF} )*100;
imf_e=IRF_.( cell2mat( [ 'e_' exovar ] ) )( 1:@{TIRF} )*100;
imf_PII1=[0;imf_PII(1:@{TIRF}-1)]; 
imf_PII2=[0;0;imf_PII(1:@{TIRF}-2)]; 
imf_PII3=[0;0;0;imf_PII(1:@{TIRF}-3)]; 
imf_PIIc1=[0;imf_PIIc(1:@{TIRF}-1)]; 
imf_PIIc2=[0;0;imf_PIIc(1:@{TIRF}-2)]; 
imf_PIIc3=[0;0;0;imf_PIIc(1:@{TIRF}-3)]; 
imf_PIIpe1=[0;imf_PIIpe(1:@{TIRF}-1)]; 
imf_PIIpe2=[0;0;imf_PIIpe(1:@{TIRF}-2)]; 
imf_PIIpe3=[0;0;0;imf_PIIpe(1:@{TIRF}-3)]; 
imf_BigPII=imf_PII+imf_PII1+imf_PII2+imf_PII3;
imf_BigPIIc=imf_PIIc+imf_PIIc1+imf_PIIc2+imf_PIIc3;
imf_BigPIIpe=imf_PIIpe+imf_PIIpe1+imf_PIIpe2+imf_PIIpe3;


imfc_pe=IRF_CONS_.( cell2mat( [ 'pe_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_pn=IRF_CONS_.( cell2mat( [ 'pn_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_lambda1=IRF_CONS_.( cell2mat( [ 'lambda1_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_lambda2=IRF_CONS_.( cell2mat( [ 'lambda2_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_ey=IRF_CONS_.( cell2mat( [ 'ey_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_ec=IRF_CONS_.( cell2mat( [ 'ec_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_k=IRF_CONS_.( cell2mat( [ 'k_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_y=IRF_CONS_.( cell2mat( [ 'y_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_c=IRF_CONS_.( cell2mat( [ 'c_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_cn=IRF_CONS_.( cell2mat( [ 'cn_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_i=IRF_CONS_.( cell2mat( [ 'i_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_PII=IRF_CONS_.( cell2mat( [ 'PII_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_PIIc=IRF_CONS_.( cell2mat( [ 'PIIc_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_PIIpe=IRF_CONS_.( cell2mat( [ 'PIIe_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_R=IRF_CONS_.( cell2mat( [ 'R_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_n=IRF_CONS_.( cell2mat( [ 'n_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_w=IRF_CONS_.( cell2mat( [ 'w_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_q=IRF_CONS_.( cell2mat( [ 'q_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_mc=IRF_CONS_.( cell2mat( [ 'mc_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_dPw=IRF_CONS_.( cell2mat( [ 'dPw_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_e=IRF_CONS_.( cell2mat( [ 'e_' exovar ] ) )( 1:@{TIRF} )*100;

imfc_PII1=[0;imfc_PII(1:@{TIRF}-1)]; 
imfc_PII2=[0;0;imfc_PII(1:@{TIRF}-2)]; 
imfc_PII3=[0;0;0;imfc_PII(1:@{TIRF}-3)]; 
imfc_PIIc1=[0;imfc_PIIc(1:@{TIRF}-1)]; 
imfc_PIIc2=[0;0;imfc_PIIc(1:@{TIRF}-2)]; 
imfc_PIIc3=[0;0;0;imfc_PIIc(1:@{TIRF}-3)]; 
imfc_PIIpe1=[0;imfc_PIIpe(1:@{TIRF}-1)]; 
imfc_PIIpe2=[0;0;imfc_PIIpe(1:@{TIRF}-2)]; 
imfc_PIIpe3=[0;0;0;imfc_PIIpe(1:@{TIRF}-3)]; 
imfc_BigPII=imfc_PII+imfc_PII1+imfc_PII2+imfc_PII3;
imfc_BigPIIc=imfc_PIIc+imfc_PIIc1+imfc_PIIc2+imfc_PIIc3;

date=xx+1;

imf_Pw(1,1)=imf_dPw(1,1);
imfc_Pw(1,1)=imfc_dPw(1,1);

for j=1:@{TIRF}-1
   imf_Pw(j+1,1)=imf_dPw(1+j,1)+imf_Pw(j,1);
   imfc_Pw(j+1,1)=imfc_dPw(1+j,1)+imfc_Pw(j,1);
end

datatex=[date imf_y imfc_y]

figure('PaperOrientation','portrait','PaperUnits','inches','PaperPosition',[0.25 0 8 10.75],'units','normalized','outerposition',[0 0 1 1])
subplot(5,2,1), s1=plot(date,imfc_y,'k-',date,imf_y,'k--');... 
title({'Output'}),xlabel('Date'),ylabel('% Deviation'),axis([0 @{TIRF} -2.5 0])
set(s1(1),'LineWidth',1);
set(s1(2),'LineWidth',1);

subplot(5,2,5), s2=plot(date,imfc_PIIc,'k-',date,imf_PIIc,'k--');... 
title({'Core Inflation Rate'}),xlabel('Date'),ylabel('% Deviation'),axis([0 @{TIRF} -0.2 0.4])
set(s2(1),'LineWidth',1);
set(s2(2),'LineWidth',1);

subplot(5,2,3), s3=plot(date,imfc_c,'k-',date,imf_c,'k--');... 
title({'Aggregate Consumption'}),xlabel('Date'),ylabel('% Deviation'),axis([0 @{TIRF} -2.5 0])
set(s3(1),'LineWidth',1);
set(s3(2),'LineWidth',1);

subplot(5,2,4), s3=plot(date,imfc_cn,'k-',date,imf_cn,'k--');... 
title({'Non-Energy Consumption'}),xlabel('Date'),ylabel('% Deviation'),axis([0 @{TIRF} -1.5 0.5])
set(s3(1),'LineWidth',1);
set(s3(2),'LineWidth',1);

subplot(5,2,2), s4=plot(date,imfc_i,'k-',date,imf_i,'k--');... 
title({'Investment'}),xlabel('Date'),ylabel('% Deviation'),axis([0 @{TIRF} -7 -1])
set(s4(1),'LineWidth',1);
set(s4(2),'LineWidth',1);

subplot(5,2,9), s5=plot(date,imfc_Pw,'k-',date,imf_Pw,'k--');... 
title({'Nominal Wage'}),xlabel('Date'),ylabel('% Change'),axis([0 @{TIRF} 0 7])
set(s5(1),'LineWidth',1);
set(s5(2),'LineWidth',1);

subplot(5,2,7), s6=plot(date,imfc_n,'k-',date,imf_n,'k--');... 
title({'Labor'}),xlabel('Date'),ylabel('% Deviation'),legend(s6(1:2),'Downward Rigid Nominal Wages','Flexible Nominal Wages','Orientation','vertical'),axis([0 @{TIRF} -1.5 2])
set(s6(1),'LineWidth',1);
set(s6(2),'LineWidth',1);

subplot(5,2,10), s7=plot(date,imfc_dPw,'k-',date,imf_dPw,'k--');... 
title({'Nominal Wage Growth Rate'}),xlabel('Date'),ylabel('%'),axis([0 @{TIRF} -1.5 2.5])
set(s7(1),'LineWidth',1);
set(s7(2),'LineWidth',1);

subplot(5,2,6), s9=plot(date,imfc_PII,'k-',date,imf_PII,'k--');... 
title({'Headline Inflation Rate'}),xlabel('Date'),ylabel('% Deviation'),axis([0 @{TIRF} -0.5 4])
set(s9(1),'LineWidth',1);
set(s9(2),'LineWidth',1);

subplot(5,2,8), s10=plot(date,imfc_w,'k-',date,imf_w,'k--');... 
title({'Real Wage'}),xlabel('Date'),ylabel('% Deviation'),axis([0 @{TIRF} -5 -1]) 
set(s10(1),'LineWidth',1);
set(s10(2),'LineWidth',1);

