// Wage_PF_Model_Referee_Report
// This model includes sticky prices, a downward rigidity on nominal wages, and oil prices.
// This file inputs the linear model in Dynare and the Holden software.
// This model was last updated June 17, 2021
// This model is used to calculate the policy functions at Period t+1

// DEFINITIONS:
// ------------
// TShadow:  Number of periods you believe the ZLB binds
// TIRF:     Number of periods for IRF graphs
// TInitIRF: Number of periods for IRF simulation
// TSimul:   Number of periods for complete simulation
// TDrop:    Number of simulation periods to be dropped before plotting

@#define TShadow =20   
@#define TIRF = 5    
@#define TSimul = 300   
@#define TDrop = 100    

@#if TShadow > TIRF
	@#define TInitIRF = TShadow
@#else
	@#define TInitIRF = TIRF
@#endif

var n c cn i y ye R q w k lambda1 lambda2 lambda3 mc PII PIIc PIIe pe pn e ec ey r dPw; // 
var nf cf cnf if yf yef Rf qf wf kf lambda1f lambda2f lambda3f mcf PIIf PIIcf PIIef pnf ef ecf eyf dPwf; // 
varexo e_e;  

//%%%%%%%%%%%%%%%%%%%%>>> BEWARE! <<<%%%%%%%%%%%%%%%%%%%%%%%
// Shadow price shocks need to be the last shocks defined! %
// ------------------------------------------------------- %
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for index in 0:( TShadow - 1 )
	varexo epsilon_shadow_@{index};
	var LAG0_shadow_@{index};
	@#for offset in 1:index
		var LAG@{offset}_shadow_@{index};
	@#endfor
	@#define offset = 10000000000
@#endfor
@#define index = 10000000000

parameters Rss qss a ky yn yss yess kss wss eyss iss css cnss ecss ess mcss phin lambda1ss lambda2ss lambda3ss dPwss;
parameters epsilonp etap kappa alpha vf vh delta beta phic xi nss pess pnss PIIstarss gammaP gammaW eyratio eccratio cncratio b1 b2; 
parameters thetaR thetaPII thetay rhop mup sigpe nx numb ii; 
parameters sige_e;   

//*******************************************
// Note: nonenergy output = y
//       output including energy = ye
//*******************************************

//*******************************************
// Calibrated Parameters
//*******************************************

load parameterfile // load parameters from Policy_Functions.m
set_param_value('numb',numb);
set_param_value('ii',ii);
nx=length(sigpe1);

set_param_value('sigpe',sigpe); // size of the energy price shock
epsilonp=6;          // 20% markup of prices over marginal cost
etap=0.75;           // probability of non-price adjustment
gammaP=1.00;         // degree of price indexation to lagged inflation
gammaW=1.00;         // degree of indexation to downward nominal wage rigidity
kappa=2.5;           // investment adjustment cost parameter       
alpha=0.33;          // capital's share of output
vf=-0.9;             // CES variable in production function
vh=-0.9;             // CES variable in household aggregate consumption
delta=0.025;         // steady-state capital depreciation rate
beta=1/1.01;         // discount factor 
phic=0.7;            // habit persistence in consumption parameter
xi=1/0.72;           // The inverse of the labor supply elasticity (ex., xi=1/3 means LSE=3)
nss=0.3;             // steady state labor
pess=1;              // steady state relative price of energy 
pnss=1;              // steady state relative price of non-energy goods 
PIIstarss=1.00;     // steady state gross inflation rate
eyratio=0.045;       // energy's share used in the production of output
eccratio=0.060;      // energy's share of consumption
cncratio=1-eccratio; // nonenergy's share of consumption
b1=eccratio^(1-vh);  // parameter in CES utility function
b2=cncratio^(1-vh);  // parameter in CES utility function

// Monetary Policy Rule Parmameters
thetaR=0.7;         // parameter on lagged interest rate
thetaPII=1.5;       // parameter on headline inflation in the policy rule, 
thetay=0.125;       // parameter on output in the monetary policy rule, model 

// Exogenous Process Parameters
rhop=0.95;         // AR coefficient on the energy price shock
mup=0;          // MA coefficient on the energy price shock

sige_e=1.0;         // standard deviation of energy shock


//*******************************************
// Steady State Values
//*******************************************

mcss=(epsilonp-1)/epsilonp;
Rss=PIIstarss/beta; // Rss is the gross nominal interest rate
qss=((1/beta)-1+delta);
a=((eyratio*pess/(pnss))^(vf-1))*(qss^vf)/(((eyratio*pess/(pnss))^(vf-1))*(qss^vf)+((alpha*mcss-(eyratio*pess/pnss))^(vf-1))*((pess/pnss)^vf));
ky=((qss*(1-a)*pnss/(pess*a))^(1/(vf-1)))*eyratio;
yn=((a*(ky^vf)+(1-a)*(eyratio^vf))^(alpha/vf))^(1/(1-alpha));
yss=yn*nss;
kss=ky*yss;
wss=(1-alpha)*mcss*yn*pnss;
eyss=eyratio*yss;                                          
iss=delta*kss;
cnss=yss-iss;
css=cnss/cncratio;
ecss=css*eccratio;
ess=ecss+eyss;
//lambda1ss=(1-beta*phic)/(vh*(1-phic)*(css^vh));
lambda1ss=1/(vh*(1-phic)*(css^vh));
lambda2ss=lambda1ss*b2*vh*(cnss^(vh-1))/pnss;
lambda3ss=lambda2ss*pnss;
phin=wss*lambda2ss/(nss^xi);
yess=pnss*yss+pess*ess;
dPwss=PIIstarss;
 
//***********************************************
// Linearized Model:  See appendix for equations
//***********************************************

model (linear);
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// 'shadow_price' is defined so that the shadow price shocks hit the equation of the constrained variable in consecutive periods: %
// ------------------------------------------------------------------------------------------------------------------------------ %
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for index in 0:( TShadow - 1 )
    LAG0_shadow_@{index} = epsilon_shadow_@{index};
	@#for offset in 1:index
		LAG@{offset}_shadow_@{index}( 0 ) = LAG@{offset-1}_shadow_@{index}( -1 );
	@#endfor
	@#define offset = 10000000000
@#endfor
@#define index = 10000000000
	
#shadow_price = 0
@#for index in 0:( TShadow - 1 )
	+ LAG@{index}_shadow_@{index}( 0 )
@#endfor
@#define index = 10000000000
;

(css^vh)*c = b1*(ecss^vh)*ec + b2*(cnss^vh)*cn; // aggregate consumption
k = iss/kss*i + (1-delta)*k(-1); // capital accumulation equation
//beta*phic*c(+1)+phic*c(-1)-(1+beta*(phic^2)+(vh-1)*vh*lambda1ss*(css^(vh-1)))*c = vh*lambda1ss*(css^(vh-1))*lambda1; //foc aggregate consumption
//beta*phic*c(+1)+phic*c(-1)-(1+beta*(phic^2)+(vh-1)*(1-phic)*(1-beta*phic))*c = (1-phic)*(1-beta*phic)*lambda1; //foc aggregate consumption
phic*c(-1)-(1 +(vh-1)*(1-phic))*c = (1-phic)*lambda1; //foc aggregate consumption
lambda1 + (vh-1)*cn = lambda2 + pn; //foc nonenergy consumption
lambda1 + (vh-1)*ec = lambda2 + pe; //foc energy consumption
w  = xi*n - lambda2 + shadow_price; //foc labor
dPw = w - w(-1) + PII + log(dPwss) - log(gammaW); 
lambda2 - R = lambda2(+1) - PII(+1); //foc bonds
pn + lambda2 = lambda3 + kappa*beta*i(+1) - kappa*(1+beta)*i + kappa*i(-1); // foc investment
(1/beta)*lambda3 = qss*(lambda2(+1)+q(+1)+pn(+1)) + (1 - delta)*lambda3(+1);  
y =	(1-alpha)*n + (alpha/(a*(kss^vf)+(1-a)*(eyss^vf)))*(a*(kss^vf)*k(-1)+(1-a)*(eyss^vf)*ey); 
y =	(cnss/yss)*cn + (iss/yss)*i; // y = cn + i
w - pn = mc + y - n; // Firm foc for labor
q =	mc + y + (vf-1-(vf*a*(kss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))))*k(-1)-(vf*(1-a)*(eyss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf)))*ey;
pe - pn = mc + y + (vf-1-(vf*(1-a)*(eyss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))))*ey-vf*a*(kss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))*k(-1);
0 = (pess*ess/yess)*pe + (pnss*yss/yess)*pn;    //headline GDP deflator
yess*PII = pnss*yss*PIIc + pess*ess*PIIe;
ye = (pnss*yss/(yess))*(y + pn) + (pess*ess/(yess))*(pe + e);
//etap*PIIc = (1-etap)*(1-etap*beta)*mc + beta*etap*PIIc(+1);
(1+beta*gammaP)*etap*PIIc = (1-etap)*(1-etap*beta)*mc + beta*etap*PIIc(+1) + etap*gammaP*PIIc(-1);
ess*e = ecss*ec + eyss*ey;
pe = rhop*pe(-1) + sigpe*e_e + sigpe*mup*e_e(-1); // energy shock
R = thetaR*R(-1)+(1-thetaR)*((thetaPII)*PIIc + thetay*(y - yf));   
//PIIe=pe-pe(-1);
PIIe=pe-pe(-1)+PII;
R = r + PII(+1); //Real interest rate

// Potential output equations
(css^vh)*cf = b1*(ecss^vh)*ecf + b2*(cnss^vh)*cnf; // aggregate consumption
kf = iss/kss*if + (1-delta)*kf(-1); // capital accumulation equation
//beta*phic*cf(+1)+phic*cf(-1)-(1+beta*(phic^2)+(vh-1)*vh*lambda1ss*(css^(vh-1)))*cf = vh*lambda1ss*(css^(vh-1))*lambda1f; //foc aggregate consumption
//beta*phic*cf(+1)+phic*cf(-1)-(1+beta*(phic^2)+(vh-1)*(1-phic)*(1-beta*phic))*cf = (1-phic)*(1-beta*phic)*lambda1f; //foc aggregate consumption
phic*cf(-1)-(1 +(vh-1)*(1-phic))*cf = (1-phic)*lambda1f; //foc aggregate consumption
lambda1f + (vh-1)*cnf = lambda2f + pnf; //foc nonenergy consumption
lambda1f + (vh-1)*ecf = lambda2f + pe; //foc energy consumption
wf  = xi*nf - lambda2f; //foc labor
dPwf = wf - wf(-1) + PIIf + log(dPwss) - log(gammaW); 
lambda2f - Rf = lambda2f(+1) - PIIf(+1); //foc bonds
pnf + lambda2f = lambda3f + kappa*beta*if(+1) - kappa*(1+beta)*if + kappa*if(-1); // foc investment
(1/beta)*lambda3f = qss*(lambda2f(+1)+qf(+1)+pnf(+1)) + (1 - delta)*lambda3f(+1);  
yf = (1-alpha)*nf + (alpha/(a*(kss^vf)+(1-a)*(eyss^vf)))*(a*(kss^vf)*kf(-1)+(1-a)*(eyss^vf)*eyf); 
yf = (cnss/yss)*cnf + (iss/yss)*if; // y = cn + i
wf - pnf = mcf + yf - nf; // Firm foc for labor
qf = mcf + yf + (vf-1-(vf*a*(kss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))))*kf(-1)-(vf*(1-a)*(eyss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf)))*eyf;
pe - pnf = mcf + yf + (vf-1-(vf*(1-a)*(eyss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))))*eyf-vf*a*(kss^vf)/(a*(kss^vf)+(1-a)*(eyss^vf))*kf(-1);
0 = (pess*ess/yess)*pe + (pnss*yss/yess)*pnf;    //headline GDP deflator
yess*PIIf = pnss*yss*PIIcf + pess*ess*PIIef;
yef = (pnss*yss/(yess))*(yf + pnf) + (pess*ess/(yess))*(pe + ef);
(1+beta*gammaP)*etap*PIIcf = (1-etap)*(1-etap*beta)*mcf + beta*etap*PIIcf(+1) + etap*gammaP*PIIcf(-1);
ess*ef = ecss*ecf + eyss*eyf;
Rf = thetaR*Rf(-1)+(1-thetaR)*thetaPII*PIIcf;   
//PIIe=pe-pe(-1);
PIIef=pe-pe(-1)+PIIf;

end;

check;
steady;

shocks;
var e_e; stderr sige_e;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Standard deviation of shadow price shocks is set to one: %
% -------------------------------------------------------- %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@#for index in 0:( TShadow - 1 )
	var epsilon_shadow_@{index} = 1;
@#endfor
@#define index = 10000000000

end;

t0 = tic;

stoch_simul( order = 1, irf = @{TInitIRF}, noprint, nograph, nomoments, periods=0 ) y PIIc PIIe PII c cn i n w q mc R dPw e pe;
//stoch_simul( order = 1, irf = @{TInitIRF}, nograph) y PIIc PIIe PII cn i n w q mc R dPw e pe;

//stoch_simul(irf = @{TInitIRF}, nomoments, periods=0 ) y PII R;

//stoch_simul(irf = @{TInitIRF}, noprint, nograph, nomoments, periods=0 ) y PII R;
 //stoch_simul(irf=200) R r PII;     

ZLBData = INITIAL_CHECKS( @{TShadow}, @{TInitIRF}, 'dPw', var_list_ );
display( sprintf( '\n%s', 'Computation time for set-up and initial feasibility checks:' ) ); toc( t0 ); 
t1 = tic;
[ IRF_, IRF_CONS_ ] = STEADYSTATE_IRF_CONS( ZLBData );
display( sprintf( '\n%s', 'Additional computation time for IRFs:' ) ); toc( t1 ); 
t2 = tic;
[ SIMU_, SIMU_CONS_ ] = SIMU_CONS(  ZLBData, @{TSimul} );
display( sprintf( '\n%s', 'Additional computation time for simulations:' ) ); toc( t2 );

%%%%%%%%%%%%%%%%%%%%%
% Generate Figures: %
% ----------------- %
%%%%%%%%%%%%%%%%%%%%%

exovars( 1, 1:( size( M_.exo_names, 1 ) - @{TShadow} ) ) = cellstr( M_.exo_names( 1:( size( M_.exo_names, 1 ) - @{TShadow} ), : ) );
vars( 1, 1:size( var_list_ ) ) = cellstr( var_list_( 1:size( var_list_ ), : ) );

xx =( 0:@{TIRF}-1 )';
for exovar = exovars
    @#define number = 0
    for var = vars
        @#define number = number +1
    end
end

yy =( 0:@{TSimul}-1-@{TDrop} )';
@#define number = 0
for var = vars
	@#define number = number +1
end 

imf_y=IRF_.( cell2mat( [ 'y_' exovar ] ) )( 1:@{TIRF} )*100;
imf_PIIc=IRF_.( cell2mat( [ 'PIIc_' exovar ] ) )( 1:@{TIRF} )*100;
imf_PII=IRF_.( cell2mat( [ 'PII_' exovar ] ) )( 1:@{TIRF} )*100;
imf_c=IRF_.( cell2mat( [ 'c_' exovar ] ) )( 1:@{TIRF} )*100;
imf_cn=IRF_.( cell2mat( [ 'cn_' exovar ] ) )( 1:@{TIRF} )*100;
imf_i=IRF_.( cell2mat( [ 'i_' exovar ] ) )( 1:@{TIRF} )*100;
imf_w=IRF_.( cell2mat( [ 'w_' exovar ] ) )( 1:@{TIRF} )*100;
imf_n=IRF_.( cell2mat( [ 'n_' exovar ] ) )( 1:@{TIRF} )*100;
imf_dPw=IRF_.( cell2mat( [ 'dPw_' exovar ] ) )( 1:@{TIRF} )*100;


imfc_y=IRF_CONS_.( cell2mat( [ 'y_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_PIIc=IRF_CONS_.( cell2mat( [ 'PIIc_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_PII=IRF_CONS_.( cell2mat( [ 'PII_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_c=IRF_CONS_.( cell2mat( [ 'c_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_cn=IRF_CONS_.( cell2mat( [ 'cn_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_i=IRF_CONS_.( cell2mat( [ 'i_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_w=IRF_CONS_.( cell2mat( [ 'w_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_n=IRF_CONS_.( cell2mat( [ 'n_' exovar ] ) )( 1:@{TIRF} )*100;
imfc_dPw=IRF_CONS_.( cell2mat( [ 'dPw_' exovar ] ) )( 1:@{TIRF} )*100;


peshock(ii,1)=sigpe;
pf_y(ii,1)=imf_y(2,1);
pf_PIIc(ii,1)=imf_PIIc(2,1);
pf_PII(ii,1)=imf_PII(2,1);
pf_c(ii,1)=imf_c(2,1);
pf_cn(ii,1)=imf_cn(2,1);
pf_i(ii,1)=imf_i(2,1);
pf_w(ii,1)=imf_w(2,1);
pf_n(ii,1)=imf_n(2,1);
pf_dPw(ii,1)=imf_dPw(2,1);
pf_Pw(ii,1)=imf_dPw(2,1)+imf_dPw(1,1);

pfc_y(ii,1)=imfc_y(2,1);
pfc_PIIc(ii,1)=imfc_PIIc(2,1);
pfc_PII(ii,1)=imfc_PII(2,1);
pfc_c(ii,1)=imfc_c(2,1);
pfc_cn(ii,1)=imfc_cn(2,1);
pfc_i(ii,1)=imfc_i(2,1);
pfc_w(ii,1)=imfc_w(2,1);
pfc_n(ii,1)=imfc_n(2,1);
pfc_dPw(ii,1)=imfc_dPw(2,1);
pfc_Pw(ii,1)=imfc_dPw(2,1)+imfc_dPw(1,1);

save policyfunctions peshock pf_y pf_PIIc pf_PII pf_c pf_cn pf_i pf_w pf_n pf_dPw pf_Pw pfc_y pfc_PIIc pfc_PII pfc_c pfc_cn pfc_i pfc_w pfc_n pfc_dPw pfc_Pw